Django Cache Pydantic
=========================

This package allows you to create pydantic instances directly inside
your django project cache and retrieve them

Status
------

.. image:: https://github.com/bindruid/django-cache-pydantic/workflows/Test/badge.svg?branch=master
   :target: https://github.com/bindruid/django-cache-pydantic/actions

.. image:: https://img.shields.io/pypi/v/django-cache-pydantic.svg
   :target: https://pypi.python.org/pypi/django-cache-pydantic

.. image:: https://img.shields.io/pypi/pyversions/django-cache-pydantic.svg
   :target: https://pypi.org/project/django-cache-pydantic

.. image:: https://img.shields.io/pypi/djversions/django-cache-pydantic.svg
   :target: https://pypi.org/project/django-cache-pydantic/

Dependencies
------------

-  Pydantic >= 2.6
-  Django >= 4.2


Install
-------

.. code:: bash

   pip install django-cache-pydantic
